@@ -26,7 +26,7 @@ namespace Epub {
       Converter();
       ~Converter();
 
-      QTextDocument *convert( const QString &fileName ) Q_DECL_OVERRIDE;
+      QTextDocument *convert( const QString &fileName ) override;
 
     private:
 
