@@ -18,6 +18,6 @@
 */
 
 #include "fax_debug.h"
-Q_LOGGING_CATEGORY(FAX_LOG, "org.kde.okular.generators.fax")
+Q_LOGGING_CATEGORY(FAX_LOG, "org.kde.okular.generators.fax", QtWarningMsg)
 
 
