@@ -50,8 +50,8 @@ class Converter::DocumentInfo
 };
 
 Converter::Converter()
-    : mTextDocument( 0 ), mCursor( 0 ),
-      mTitleInfo( 0 ), mDocumentInfo( 0 )
+    : mTextDocument( nullptr ), mCursor( nullptr ),
+      mTitleInfo( nullptr ), mDocumentInfo( nullptr )
 {
 }
 
@@ -66,7 +66,7 @@ QTextDocument* Converter::convert( const QString &fileName )
     Document fbDocument( fileName );
     if ( !fbDocument.open() ) {
         emit error( fbDocument.lastErrorString(), -1 );
-        return 0;
+        return nullptr;
     }
 
     mTextDocument = new QTextDocument;
@@ -96,7 +96,7 @@ QTextDocument* Converter::convert( const QString &fileName )
     if ( documentElement.tagName() != QLatin1String( "FictionBook" ) ) {
         emit error( i18n( "Document is not a valid FictionBook" ), -1 );
         delete mCursor;
-        return 0;
+        return nullptr;
     }
 
     /**
@@ -107,7 +107,7 @@ QTextDocument* Converter::convert( const QString &fileName )
         if ( element.tagName() == QLatin1String( "binary" ) ) {
             if ( !convertBinary( element ) ) {
                 delete mCursor;
-                return 0;
+                return nullptr;
             }
         }
 
@@ -122,7 +122,7 @@ QTextDocument* Converter::convert( const QString &fileName )
         if ( element.tagName() == QLatin1String( "description" ) ) {
             if ( !convertDescription( element ) ) {
                 delete mCursor;
-                return 0;
+                return nullptr;
             }
         } else if ( element.tagName() == QLatin1String( "body" ) ) {
             if ( !mTitleInfo->mCoverPage.isNull() ) {
@@ -164,7 +164,7 @@ QTextDocument* Converter::convert( const QString &fileName )
 
             if ( !convertBody( element ) ) {
                 delete mCursor;
-                return 0;
+                return nullptr;
             }
         }
 
