@@ -32,7 +32,7 @@ class Converter : public Okular::TextDocumentConverter
     Converter();
     ~Converter();
 
-    virtual Okular::Document::OpenResult convertWithPassword( const QString &fileName, const QString &password );
+    Okular::Document::OpenResult convertWithPassword( const QString &fileName, const QString &password ) override;
 
   private:
     bool convertBody( const QDomElement &element );
