@@ -18,11 +18,16 @@
 #include <QTreeWidget>
 #include <QTemporaryFile>
 
-#include <kglobal.h>
-#include <kicon.h>
-#include <klocale.h>
-#include <kmimetype.h>
+#include <QIcon>
+#include <KLocalizedString>
+#include <QMimeType>
+#include <QMimeDatabase>
 #include <kstandardguiitem.h>
+#include <KFormat>
+#include <KConfigGroup>
+#include <QDialogButtonBox>
+#include <QPushButton>
+#include <QVBoxLayout>
 #include <krun.h>
 
 #include "core/document.h"
@@ -35,22 +40,33 @@ static const int EmbeddedFileRole = Qt::UserRole + 100;
 static QString dateToString( const QDateTime & date )
 {
 	return date.isValid()
-		? KGlobal::locale()->formatDateTime( date, KLocale::LongDate, true )
+        ? QLocale().toString( date, QLocale::LongFormat )
 		: i18nc( "Unknown date", "Unknown" );
 }
 
-EmbeddedFilesDialog::EmbeddedFilesDialog(QWidget *parent, const Okular::Document *document) : KDialog(parent)
+EmbeddedFilesDialog::EmbeddedFilesDialog(QWidget *parent, const Okular::Document *document) : QDialog(parent)
 {
-	setCaption(i18nc("@title:window", "Embedded Files"));
-	setButtons(Close | User1 | User2);
-	setDefaultButton(Close);
-	setButtonGuiItem(User1, KStandardGuiItem::save());
-	setButtonGuiItem(User2, KGuiItem(i18nc("@action:button", "View"), "document-open"));
-	enableButton(User1, false);
-	enableButton(User2, false);
+	setWindowTitle(i18nc("@title:window", "Embedded Files"));
+	QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close);
+	QVBoxLayout *mainLayout = new QVBoxLayout;
+	setLayout(mainLayout);
+	mUser1Button = new QPushButton;
+	buttonBox->addButton(mUser1Button, QDialogButtonBox::ActionRole);
+	connect(buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accept);
+	connect(buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
+	buttonBox->button(QDialogButtonBox::Close)->setDefault(true);
+	KGuiItem::assign(mUser1Button, KStandardGuiItem::save());
+	mUser1Button->setEnabled(false);
+
+	mUser2Button = new QPushButton;
+	buttonBox->addButton(mUser2Button, QDialogButtonBox::ActionRole);
+	KGuiItem::assign(mUser2Button, KGuiItem(i18nc("@action:button", "View"), "document-open"));
+	mUser2Button->setEnabled(false);
 
 	m_tw = new QTreeWidget(this);
-	setMainWidget(m_tw);
+	mainLayout->addWidget(m_tw);
+	mainLayout->addWidget(buttonBox);
+
 	QStringList header;
 	header.append(i18nc("@title:column", "Name"));
 	header.append(i18nc("@title:column", "Description"));
@@ -66,39 +82,39 @@ EmbeddedFilesDialog::EmbeddedFilesDialog(QWidget *parent, const Okular::Document
 	{
 		QTreeWidgetItem *twi = new QTreeWidgetItem();
 		twi->setText(0, ef->name());
-		KMimeType::Ptr mime = KMimeType::findByPath( ef->name(), 0, true );
-		if (mime)
+		QMimeDatabase db;
+		QMimeType mime = db.mimeTypeForFile( ef->name(), QMimeDatabase::MatchExtension);
+		if (mime.isValid())
 		{
-			twi->setIcon(0, KIcon(mime->iconName()));
+			twi->setIcon(0, QIcon::fromTheme(mime.iconName()));
 		}
 		twi->setText(1, ef->description());
-		twi->setText(2, ef->size() <= 0 ? i18nc("Not available size", "N/A") : KGlobal::locale()->formatByteSize(ef->size()));
+		twi->setText(2, ef->size() <= 0 ? i18nc("Not available size", "N/A") : KFormat().formatByteSize(ef->size()));
 		twi->setText(3, dateToString( ef->creationDate() ) );
 		twi->setText(4, dateToString( ef->modificationDate() ) );
 		twi->setData( 0, EmbeddedFileRole, qVariantFromValue( ef ) );
 		m_tw->addTopLevelItem(twi);
 	}
-        // Having filled the columns, it is nice to resize them to be able to read the contents
-        for (int lv = 0; lv <  m_tw->columnCount(); ++lv) {
-                m_tw->resizeColumnToContents(lv);
-        }
-        // This is a bit dubious, but I'm not seeing a nice way to say "expand to fit contents"
-        m_tw->setMinimumWidth(640);
-        m_tw->updateGeometry();
+	// Having filled the columns, it is nice to resize them to be able to read the contents
+	for (int lv = 0; lv <  m_tw->columnCount(); ++lv) {
+		m_tw->resizeColumnToContents(lv);
+	}
+	// This is a bit dubious, but I'm not seeing a nice way to say "expand to fit contents"
+	m_tw->setMinimumWidth(640);
+	m_tw->updateGeometry();
 
-	connect(this, SIGNAL(user1Clicked()), this, SLOT(saveFile()));
-	connect(this, SIGNAL(user2Clicked()), this, SLOT(viewFile()));
-
-	connect(m_tw, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(attachViewContextMenu(QPoint)));
-	connect(m_tw, SIGNAL(itemSelectionChanged()), this, SLOT(updateSaveButton()));
-	connect(m_tw, SIGNAL(itemDoubleClicked(QTreeWidgetItem*,int)), this, SLOT(viewFileItem(QTreeWidgetItem*,int)));
+	connect(mUser1Button, SIGNAL(clicked()), this, SLOT(saveFile()));
+	connect(mUser2Button, SIGNAL(clicked()), this, SLOT(viewFile()));
+	connect(m_tw, &QWidget::customContextMenuRequested, this, &EmbeddedFilesDialog::attachViewContextMenu);
+	connect(m_tw, &QTreeWidget::itemSelectionChanged, this, &EmbeddedFilesDialog::updateSaveButton);
+	connect(m_tw, &QTreeWidget::itemDoubleClicked, this, &EmbeddedFilesDialog::viewFileItem);
 }
 
 void EmbeddedFilesDialog::updateSaveButton()
 {
 	bool enable = (m_tw->selectedItems().count() > 0);
-	enableButton(User1, enable);
-	enableButton(User2, enable);
+	mUser1Button->setEnabled(enable);
+	mUser2Button->setEnabled(enable);
 }
 
 void EmbeddedFilesDialog::saveFile()
@@ -137,8 +153,8 @@ void EmbeddedFilesDialog::attachViewContextMenu( const QPoint& /*pos*/ )
         return;
 
     QMenu menu( this );
-    QAction* saveAsAct = menu.addAction( KIcon( "document-save-as" ), i18nc( "@action:inmenu", "&Save As..." ) );
-    QAction* viewAct = menu.addAction( KIcon( "document-open" ), i18nc( "@action:inmenu", "&View..." ) );
+    QAction* saveAsAct = menu.addAction( QIcon::fromTheme( QStringLiteral("document-save-as") ), i18nc( "@action:inmenu", "&Save As..." ) );
+    QAction* viewAct = menu.addAction( QIcon::fromTheme( QStringLiteral("document-open" ) ), i18nc( "@action:inmenu", "&View..." ) );
 
     QAction* act = menu.exec( QCursor::pos() );
     if ( !act )
@@ -186,4 +202,4 @@ void EmbeddedFilesDialog::saveFile( Okular::EmbeddedFile* ef )
     GuiUtils::saveEmbeddedFile( ef, this );
 }
 
-#include "embeddedfilesdialog.moc"
+#include "moc_embeddedfilesdialog.cpp"
