@@ -1,6 +1,9 @@
 /***************************************************************************
  *   Copyright (C) 2004 by Enrico Ros <eros.kde@email.it>                  *
  *   Copyright (C) 2004 by Albert Astals Cid <aacid@kde.org>               *
+ *   Copyright (C) 2017    Klarälvdalens Datakonsult AB, a KDAB Group      *
+ *                         company, info@kdab.com. Work sponsored by the   *
+ *                         LiMux project of the city of Munich             *
  *                                                                         *
  *   With portions of code from kpdf/kpdf_pagewidget.h by:                 *
  *     Copyright (C) 2002 by Wilco Greven <greven@kde.org>                 *
@@ -36,6 +39,7 @@ class DocumentViewport;
 class Annotation;
 class MovieAction;
 class RenditionAction;
+class PixmapRequest;
 }
 
 class FormWidgetIface;
@@ -188,12 +192,18 @@ Q_OBJECT
         void updatePageStep();
 
         void addWebShortcutsMenu( QMenu * menu, const QString & text );
+        QMenu* createProcessLinkMenu( PageViewItem *item, const QPoint & eventPos );
         // used when selecting stuff, makes the view scroll as necessary to keep the mouse inside the view
         void scrollPosIntoView( const QPoint & pos );
 
         // called from slots to turn off trim modes mutually exclusive to id
         void updateTrimMode( int except_id );
 
+        // handle link clicked
+        bool mouseReleaseOverLink( const Okular::ObjectRect * rect ) const;
+
+        void createAnnotationsVideoWidgets(PageViewItem *item, const QLinkedList< Okular::Annotation * > &annotations);
+
         // don't want to expose classes in here
         class PageViewPrivate * d;
 
