@@ -2,6 +2,9 @@
  *   Copyright (C) 2017 by Tobias Deiminger <haxtibal@t-online.de>         *
  *   Copyright (C) 2004-2005 by Enrico Ros <eros.kde@email.it>             *
  *   Copyright (C) 2004-2006 by Albert Astals Cid <aacid@kde.org>          *
+ *   Copyright (C) 2017    Klarälvdalens Datakonsult AB, a KDAB Group      *
+ *                         company, info@kdab.com. Work sponsored by the   *
+ *                         LiMux project of the city of Munich             *
  *                                                                         *
  *   With portions of code from kpdf/kpdf_pagewidget.cc by:                *
  *     Copyright (C) 2002 by Wilco Greven <greven@kde.org>                 *
@@ -36,7 +39,7 @@ static const int handleSizeHalf = handleSize / 2;
 
 bool AnnotationDescription::isValid() const
 {
-    return ( annotation != 0 );
+    return ( annotation != nullptr );
 }
 
 void AnnotationDescription::invalidate()
@@ -48,7 +51,7 @@ void AnnotationDescription::invalidate()
 
 AnnotationDescription::AnnotationDescription( PageViewItem * newPageViewItem, const QPoint& eventPos )
 {
-    const Okular::AnnotationObjectRect * annObjRect = 0;
+    const Okular::AnnotationObjectRect * annObjRect = nullptr;
     if ( newPageViewItem )
     {
         const QRect & uncroppedPage = newPageViewItem->uncroppedGeometry();
@@ -381,7 +384,7 @@ Qt::CursorShape MouseAnnotation::cursor() const
         }
         else if ( m_mouseOverAnnotation.annotation->subType() == Okular::Annotation::AScreen )
         {
-            if ( GuiUtils::renditionMovieFromScreenAnnotation( static_cast< const Okular::ScreenAnnotation * >( m_mouseOverAnnotation.annotation ) ) != 0 )
+            if ( GuiUtils::renditionMovieFromScreenAnnotation( static_cast< const Okular::ScreenAnnotation * >( m_mouseOverAnnotation.annotation ) ) != nullptr )
             {
                 return Qt::PointingHandCursor;
             }
@@ -400,6 +403,19 @@ Qt::CursorShape MouseAnnotation::cursor() const
     return Qt::ArrowCursor;
 }
 
+void MouseAnnotation::updateAnnotationPointers()
+{
+    if (m_focusedAnnotation.annotation)
+    {
+        m_focusedAnnotation.annotation = m_document->page( m_focusedAnnotation.pageNumber )->annotation( m_focusedAnnotation.annotation->uniqueName() );
+    }
+
+    if (m_mouseOverAnnotation.annotation)
+    {
+        m_mouseOverAnnotation.annotation = m_document->page( m_mouseOverAnnotation.pageNumber )->annotation( m_mouseOverAnnotation.annotation->uniqueName() );
+    }
+}
+
 void MouseAnnotation::cancel()
 {
     if ( isActive() )
