@@ -2,6 +2,9 @@
  *   Copyright (C) 2017 by Tobias Deiminger <haxtibal@t-online.de>         *
  *   Copyright (C) 2004-2005 by Enrico Ros <eros.kde@email.it>             *
  *   Copyright (C) 2004-2006 by Albert Astals Cid <aacid@kde.org>          *
+ *   Copyright (C) 2017    Klarälvdalens Datakonsult AB, a KDAB Group      *
+ *                         company, info@kdab.com. Work sponsored by the   *
+ *                         LiMux project of the city of Munich             *
  *                                                                         *
  *   With portions of code from kpdf/kpdf_pagewidget.cc by:                *
  *     Copyright (C) 2002 by Wilco Greven <greven@kde.org>                 *
@@ -43,7 +46,7 @@ class AnnotationDescription
 {
 public:
     AnnotationDescription()
-        : annotation( 0 ), pageViewItem( 0 ), pageNumber( 0 ) {}
+        : annotation( nullptr ), pageViewItem( nullptr ), pageNumber( 0 ) {}
     AnnotationDescription( PageViewItem * newPageViewItem, const QPoint& eventPos );
     bool isValid() const;
     void invalidate();
@@ -113,6 +116,9 @@ public:
 
     Qt::CursorShape cursor() const;
 
+    // needs to be called after document save
+    void updateAnnotationPointers();
+
     enum MouseAnnotationState {
         StateInactive,
         StateFocused,
